Conversational Space Map App
****************************

|PyPI version| |PyPI status| |PyPI license| |PyPI pyversions|


.. |PyPI status| image:: https://img.shields.io/pypi/status/ConversationalSpaceMapApp
   :alt: PyPI - Status
.. |PyPI version| image:: https://img.shields.io/pypi/v/ConversationalSpaceMapApp
   :alt: PyPI - Version
.. |PyPI license| image:: https://img.shields.io/pypi/l/ConversationalSpaceMapApp
   :alt: PyPI - License
.. |PyPI pyversions| image:: https://img.shields.io/pypi/pyversions/ConversationalSpaceMapApp.svg
   :target: https://pypi.python.org/pypi/ConversationalSpaceMapApp/


Generate conversational space maps for interview data, inspired by Saunders et al. (2023, pp. 458-460).

.. image:: https://raw.githubusercontent.com/manuelbieri/ConversationalSpaceMapApp/master/src/conversationalspacemapapp/resources/Screenshot.png
   :width: 95%
   :alt: App screenshot
   :align: center

Quickstart
============================

Installation - PyPi
----------------------------

Note: This quickstart guide assumes that you have already installed Python.

1. Install via terminal

.. code-block:: bash

    $ pip install ConversationalSpaceMapApp

2. Run the app in the terminal.

.. code-block:: bash

    $ csm-run


Installation - GitHub (with packaging)
----------------------------------------

Note: This quickstart guide assumes that you have already installed Python and Git.

1. Download or clone the repository

.. code-block:: bash

    $ git clone https://github.com/manuelbieri/ConversationalSpaceMap.git

2. Create a virtual environment.

3. Install dependencies (in your virtual environment).

.. code-block:: bash

    $ pip install .

4. Run the app (`see this tutorial <https://docs.beeware.org/en/latest/tutorial/tutorial-3.html#building-your-application>`_).

.. code-block:: bash

    $ briefcase run

(5. Package the app for local installation)

.. code-block:: bash

    $ briefcase package

How to use
============================

.. image:: https://raw.githubusercontent.com/manuelbieri/ConversationalSpaceMapApp/master/src/conversationalspacemapapp/resources/Menubar.png
   :width: 95%
   :align: center
   :alt: Menubar screenshot

References
============================
**Saunders, Mark, Philip Lewis, and Adrian Thornhill**, *Research methods for business students*, 9 ed., Harlow, England: Pearson, 2023.
